<?php namespace prlbr\mouse;

/* Copyright 2019 Martin Janecke <mouse@prlbr.de>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/* This EXPERIMENTAL submodule displays the newest pages that the crawler of the
 * main module x-mouse found. The number of displayed pages can be configured.
 * Use this submodule with the same links provided to the main module. Example:
 *
 * @x-mouse: news=8
 * [x-mouse/news]->https://example.org/
 */

require_once __DIR__ . '/../assets/functions.php';


/* Returnig a closure that returns the form instead of returning the form
 * directly enables the Aneamal translator to use this module multiple times
 * with a single include.
 */
return function (
	array $_,
	int $max = 99
):	string
{
	// for backwards compatibility with Aneamal 27
	aneamal_v28_parameters ($_);

	// check whether the crawler created a news file for the given links
	$newsfile = $_['root'] . '/aneamal/cache/mouse-' . realm ($_['links']) . '-news.txt';
	if (!is_readable ($newsfile)):
		return '<!-- x-mouse/news: No readable data found. Make sure to use '
			.  '[x-mouse/news] with the same links that you provide to the '
			.  'main module [x-mouse]. -->'
		;
	endif;

	// get the number of pages to be shown; can be set with @x-mouse:news=...
	$parameters = parameters ($_['meta']);
	$count = intval ($parameters['news'] ?? 6);

	// get data about at most the requested number of newly found pages
	$news = [];
	$flags = FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES;
	foreach (array_slice (file ($newsfile, $flags), -$count) as $i => $record):
		$news[] = explode ("\t", $record);
	endforeach;

	// prepare HTML output
	$out[] = "<div class='x-mouse-news'><ol>";
	foreach (array_reverse ($news) as $new):
		$url = esc ($new[0]);
		$time = esc ($new[1] ?? '');
		$title = esc ($new[2] ?? '???');
		$out[] = "<li data-time='$time'><a href='$url'>$title<br><small>$url</small></a></li>";
	endforeach;
	$out[] = '</ol></div>';

	return implode ($out);
};

// The End